import { ConstructFactory, ConstructFactoryGetInstanceProps } from '@aws-amplify/plugin-types';
import { AmplifyFunctionProps, AmplifyLambdaFunction } from '@aws-amplify/function-construct-alpha';
export type AmplifyFunctionFactoryBaseProps = {
    /**
     * A name for the function that is used to disambiguate it from other functions in the project
     */
    name: string;
};
export type AmplifyFunctionFactoryBuildProps = AmplifyFunctionFactoryBaseProps & Omit<AmplifyFunctionProps, 'absoluteCodePath'> & {
    /**
     * The command to run that generates built function code.
     * This command is run from the directory where this factory is called
     */
    buildCommand: string;
    /**
     * The buildCommand is expected to place build artifacts at this location.
     * This path can be relative or absolute. If relative, the absolute path is calculated based on the directory where this factory is called
     */
    outDir: string;
};
export type AmplifyFunctionFactoryFromDirProps = AmplifyFunctionFactoryBaseProps & Omit<AmplifyFunctionProps, 'absoluteCodePath'> & {
    /**
     * The location of the pre-built function code.
     * Can be a directory or a .zip file.
     * Can be a relative or absolute path. If relative, the absolute path is calculated based on the directory where this factory is called.
     */
    codePath: string;
};
/**
 * Create Lambda functions in the context of an Amplify backend definition
 */
export declare class AmplifyFunctionFactory implements ConstructFactory<AmplifyLambdaFunction> {
    private readonly props;
    private static commandExecutor;
    private generator;
    /**
     * Create a new AmplifyFunctionFactory
     */
    private constructor();
    /**
     * Create a function from a directory that contains pre-built code
     */
    static fromDir: (props: AmplifyFunctionFactoryFromDirProps) => AmplifyFunctionFactory;
    /**
     * Create a function by executing a build command that places build artifacts at a specified location
     *
     * TODO: Investigate long-term function building strategy: https://github.com/aws-amplify/amplify-backend/issues/92
     */
    static build: (props: AmplifyFunctionFactoryBuildProps) => Promise<AmplifyFunctionFactory>;
    /**
     * Creates an instance of AmplifyFunction within the provided Amplify context
     */
    getInstance: ({ constructContainer, }: ConstructFactoryGetInstanceProps) => AmplifyLambdaFunction;
}
/**
 * Alias for AmplifyFunctionFactory
 */
export declare const Func: typeof AmplifyFunctionFactory;
//# sourceMappingURL=factory.d.ts.map